==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1DeploymentStrategyFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface ExtensionsV1beta1DeploymentStrategyFluent<A extends ExtensionsV1beta1DeploymentStrategyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public ExtensionsV1beta1RollingUpdateDeployment getRollingUpdate();
    public ExtensionsV1beta1RollingUpdateDeployment buildRollingUpdate();
    public A withRollingUpdate(ExtensionsV1beta1RollingUpdateDeployment rollingUpdate);
    public Boolean hasRollingUpdate();
    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(ExtensionsV1beta1RollingUpdateDeployment item);
    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(ExtensionsV1beta1RollingUpdateDeployment item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();

    public interface RollingUpdateNested<N> extends io.kubernetes.client.fluent.Nested<N>,ExtensionsV1beta1RollingUpdateDeploymentFluent<ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<N>>{

        
    public N and();    public N endRollingUpdate();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1DeploymentStrategyFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface ExtensionsV1beta1DeploymentStrategyFluent<A extends ExtensionsV1beta1DeploymentStrategyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public ExtensionsV1beta1RollingUpdateDeployment getRollingUpdate();
    public ExtensionsV1beta1RollingUpdateDeployment buildRollingUpdate();
    public A withRollingUpdate(ExtensionsV1beta1RollingUpdateDeployment rollingUpdate);
    public Boolean hasRollingUpdate();
    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(ExtensionsV1beta1RollingUpdateDeployment item);
    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
    public ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(ExtensionsV1beta1RollingUpdateDeployment item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface RollingUpdateNested<N> extends io.kubernetes.client.fluent.Nested<N>,ExtensionsV1beta1RollingUpdateDeploymentFluent<ExtensionsV1beta1DeploymentStrategyFluent.RollingUpdateNested<N>>{

        
    public N and();    public N endRollingUpdate();
}


}
